==> ejc-settlementmanage-impl-3.0.0-20220425.073851-9-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookVisaScheduleDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-收入明细表-工程结算签证明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_visa_schedule")
public class SettlementBookVisaScheduleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="visa_code")
    private java.lang.String visaCode; // 签证编码
    @TableField(value="visa_content")
    private java.lang.String visaContent; // 签证内容
    @TableField(value="extax_price")
    private java.math.BigDecimal extaxPrice; // 除税金额
    @TableField(value="intax_price")
    private java.math.BigDecimal intaxPrice; // 含税金额
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 签证编码
     */
    public java.lang.String getVisaCode() {
        return visaCode;
    }

    /**
     * 签证编码
     */
    public void setVisaCode(java.lang.String visaCode) {
        this.visaCode = visaCode;
    }
    /**
     * 签证内容
     */
    public java.lang.String getVisaContent() {
        return visaContent;
    }

    /**
     * 签证内容
     */
    public void setVisaContent(java.lang.String visaContent) {
        this.visaContent = visaContent;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExtaxPrice() {
        return extaxPrice;
    }

    /**
     * 除税金额
     */
    public void setExtaxPrice(java.math.BigDecimal extaxPrice) {
        this.extaxPrice = extaxPrice;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getIntaxPrice() {
        return intaxPrice;
    }

    /**
     * 含税金额
     */
    public void setIntaxPrice(java.math.BigDecimal intaxPrice) {
        this.intaxPrice = intaxPrice;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20221202.092227-124-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookVisaScheduleDetailEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-收入明细表-工程结算签证明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_visa_schedule")
public class SettlementBookVisaScheduleDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="visa_code")
    private java.lang.String visaCode; // 签证编码
    @TableField(value="visa_content")
    private java.lang.String visaContent; // 签证内容
    @TableField(value="extax_price")
    private java.math.BigDecimal extaxPrice; // 除税金额
    @TableField(value="intax_price")
    private java.math.BigDecimal intaxPrice; // 含税金额
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="section")
    private String section; // 区段
    @TableField(value="name")
    private String name; // 子目名称
    @TableField(value="subitem_desc")
    private String subitemDesc; // 子目特征描述
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 签证编码
     */
    public java.lang.String getVisaCode() {
        return visaCode;
    }

    /**
     * 签证编码
     */
    public void setVisaCode(java.lang.String visaCode) {
        this.visaCode = visaCode;
    }
    /**
     * 签证内容
     */
    public java.lang.String getVisaContent() {
        return visaContent;
    }

    /**
     * 签证内容
     */
    public void setVisaContent(java.lang.String visaContent) {
        this.visaContent = visaContent;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExtaxPrice() {
        return extaxPrice;
    }

    /**
     * 除税金额
     */
    public void setExtaxPrice(java.math.BigDecimal extaxPrice) {
        this.extaxPrice = extaxPrice;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getIntaxPrice() {
        return intaxPrice;
    }

    /**
     * 含税金额
     */
    public void setIntaxPrice(java.math.BigDecimal intaxPrice) {
        this.intaxPrice = intaxPrice;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }
}
